From 4721accb32717dd310ae2abbeca266360c7720d3 Mon Sep 17 00:00:00 2001
From: tpearson <tpearson@283d02a7-25f6-0310-bc7c-ecb5cbfe19da>
Date: Wed, 22 Jun 2011 05:27:10 +0000
Subject: Fix kdenetwork Qt3 FTBFS

git-svn-id: svn://anonsvn.kde.org/home/kde/branches/trinity/kdenetwork@1237929 283d02a7-25f6-0310-bc7c-ecb5cbfe19da
---
 kopete/kopete/chatwindow/chattexteditpart.cpp      |   2 +-
 kopete/kopete/chatwindow/krichtexteditpart.cpp     |   2 +-
 kopete/plugins/history/historydialog.cpp           |   2 +-
 kopete/protocols/configure.in.in                   | 110 +--------------------
 .../groupwise/libgroupwise/responseprotocol.cpp    |   6 +-
 kopete/protocols/irc/ircsignalhandler.h            |  26 ++---
 kopete/protocols/msn/Makefile.am                   |   1 +
 kopete/protocols/msn/msnswitchboardsocket.cpp      |   2 +-
 kopete/protocols/yahoo/libkyahoo/sendfiletask.cpp  |   2 +-
 .../protocols/yahoo/libkyahoo/sendpicturetask.cpp  |   2 +-
 10 files changed, 26 insertions(+), 129 deletions(-)

diff --git a/kopete/kopete/chatwindow/chattexteditpart.cpp b/kopete/kopete/chatwindow/chattexteditpart.cpp
index d3d3afc4..9936b234 100644
--- a/kopete/kopete/chatwindow/chattexteditpart.cpp
+++ b/kopete/kopete/chatwindow/chattexteditpart.cpp
@@ -107,7 +107,7 @@ KDictSpellingHighlighter* ChatTextEditPart::spellHighlighter()
 }
 
 // NAUGHTY, BAD AND WRONG! (but needed to fix nick complete bugs)
-#include <private/tqrichtext_p.h>
+#include <tqrichtext_p.h>
 class EvilTextEdit : public KTextEdit
 {
 public:
diff --git a/kopete/kopete/chatwindow/krichtexteditpart.cpp b/kopete/kopete/chatwindow/krichtexteditpart.cpp
index 61149c0d..090c479b 100644
--- a/kopete/kopete/chatwindow/krichtexteditpart.cpp
+++ b/kopete/kopete/chatwindow/krichtexteditpart.cpp
@@ -10,7 +10,7 @@
 #include <tqclipboard.h>
 #include <tqevent.h>
 #include <kparts/genericfactory.h>
-#include <private/tqrichtext_p.h>
+#include <tqrichtext_p.h>
 
 #include "krichtexteditpart.h"
 #include "krichtexteditpart.moc"
diff --git a/kopete/plugins/history/historydialog.cpp b/kopete/plugins/history/historydialog.cpp
index 2496f893..16db9170 100644
--- a/kopete/plugins/history/historydialog.cpp
+++ b/kopete/plugins/history/historydialog.cpp
@@ -496,7 +496,7 @@ void HistoryDialog::slotSearch()
 				if (!file.isOpen())
 				{
 					kdWarning(14310) << k_funcinfo << "Error opening " <<
-							file.name() << ": " << file.errorString().data() << endl;
+							file.name() << ": " << file.errorString().ascii() << endl;
 					continue;
 				}
 
diff --git a/kopete/protocols/configure.in.in b/kopete/protocols/configure.in.in
index 05da3ea5..0008f19e 100644
--- a/kopete/protocols/configure.in.in
+++ b/kopete/protocols/configure.in.in
@@ -24,78 +24,9 @@ if test "$ac_libgadu_libs" != "" ; then
 	LIBGG_LIBS="-L$ac_libgadu_libs"
 fi
 
-if test "x$with_external_libgadu" != xno; then
-	ac_save_LIBS="$LIBS"
-	ac_save_CFLAGS="$CFLAGS"
-	LIBS="$LIBGG_LIBS -lgadu $LIBPTHREAD"
-	CFLAGS="$CFLAGS $LIBGG_INCLUDES"
-	AC_MSG_CHECKING([libgadu version 1.5(rcX) with pthread support])
-	AC_TRY_RUN(
-	[
-	
-	#include <libgadu.h>
-	#include <stdio.h>
-	#include <string.h>
-		
-	int main()
-	{
-#if defined __GG_LIBGADU_HAVE_PTHREAD && defined GG_LOGIN60
-		int maj, min, date, items;
-		const char *libgadu_version = gg_libgadu_version();
-
-		items = sscanf( libgadu_version, "%u.%u.%u", &maj,&min,&date );
-
-		if ( items != 3 ) { /* version in YYYYDDMM format only */
-			sscanf( libgadu_version, "%u", &date );
-
-			if ( date < 20040520 )
-				return 1;
-			else
-				return 0;
-		}
-
-		if ( maj != 1 ) {
-			return 1;
-		}
-		if ( ( min == 4 || min == 5 ) && date < 20040520 ) {
-			return 1;
-		}
-
-		if ( min == 5 || min == 6 ){
-			return 0;
-		}
-			     
-#endif
-	    return 1;
-	}
-	], [
-	LIBGG_LIBS="$LIBGG_LIBS -lgadu $LIBPTHREAD"
-	AC_MSG_RESULT([yes])
-	COMPILE_GADU=true
-	use_libgadu_copy=
-	], [
-	AC_MSG_RESULT([no])
-	])
-	LIBS="$ac_save_LIBS"
-	CFLAGS="$ac_save_CFLAGS"
-
-	if test "x$with_external_libgadu" != xcheck && test -z "$COMPILE_GADU"; then
-		AC_MSG_ERROR([--with-external-libgadu was given, but test for libgadu failed])
-	fi
-fi
-
-if test -z "$COMPILE_GADU"; then
-	AC_MSG_CHECKING([if supplied libgadu-copy can be used])
-	if test "$kde_use_threading" = "yes"; then
-		AC_MSG_RESULT([yes])
-		use_libgadu_copy=yes
-		COMPILE_GADU=true
-	else
-		AC_MSG_RESULT([no (no pthread), support for Gadu-Gadu will be disabled])
-		use_libgadu_copy=
-		COMPILE_GADU=
-	fi
-fi
+dnl This may need a test still for compatibility
+COMPILE_GADU=true
+use_libgadu_copy=
 
 AC_SUBST(LIBGG_INCLUDES)
 AC_SUBST(LIBGG_LIBS)
@@ -103,41 +34,6 @@ AC_SUBST(COMPILE_GADU)
 AM_CONDITIONAL(include_gadu, test -n "$COMPILE_GADU")
 AM_CONDITIONAL(include_libggcopy, test -n "$use_libgadu_copy")
 
-if test "$use_libgadu_copy" = "yes"; then
-	AM_CONFIG_HEADER(kopete/protocols/gadu/libgadu/libgadu-config.h)
-
-	if test "$ac_cv_c_bigendian" = "yes"; then
-		AC_DEFINE_UNQUOTED([__GG_LIBGADU_BIGENDIAN], 1, [Define if big endian])
-	fi
-	KDE_CHECK_LONG_LONG()
-	if test "$kde_cv_c_long_long" = "yes"; then
-		AC_DEFINE_UNQUOTED([__GG_LIBGADU_HAVE_LONG_LONG], 1, [long long support])
-	fi
-	KDE_CHECK_SSL()
-	if test  "$have_ssl" = "yes"; then
-	AC_DEFINE_UNQUOTED([__GG_LIBGADU_HAVE_OPENSSL], 1, [Define if SSL support is available])
-	fi
-	AC_MSG_CHECKING([for C99-compatible vsnprintf()])
-	AC_TRY_RUN(
-	[
-		#include <stdio.h>
-		int main()
-		{
-			char tmp;
-			return (snprintf(&tmp, sizeof(tmp), "test") != 4);
-		}
-	],[
-		AC_MSG_RESULT([yes])
-		AC_DEFINE_UNQUOTED([__GG_LIBGADU_HAVE_C99_VSNPRINTF], 1, [C99 vsnprintf() available])
-	], [
-		 AC_MSG_RESULT([no])
-	])
-	AC_CHECK_FUNCS([va_copy],
-		       [AC_DEFINE_UNQUOTED([__GG_LIBGADU_HAVE_VA_COPY], 1, [va_copy])],[])
-	AC_CHECK_FUNCS([_va_copy],
-		       [AC_DEFINE_UNQUOTED([__GG_LIBGADU_HAVE__VA_COPY], 1, [__va_copy])],[])
-fi
-
 KDE_PKG_CHECK_MODULES(IDN, libidn, have_libidn=yes, have_libidn=no)
 if test x$have_libidn = xno; then
 	AC_MSG_WARN([Libidn not found, Kopete Jabber plugin will not be compiled])
diff --git a/kopete/protocols/groupwise/libgroupwise/responseprotocol.cpp b/kopete/protocols/groupwise/libgroupwise/responseprotocol.cpp
index 1145583a..652cd5f2 100644
--- a/kopete/protocols/groupwise/libgroupwise/responseprotocol.cpp
+++ b/kopete/protocols/groupwise/libgroupwise/responseprotocol.cpp
@@ -299,16 +299,16 @@ bool ResponseProtocol::readGroupWiseLine( TQCString & line )
 	while ( true )
 	{
 		TQ_UINT8 c;
-		
+
 		if (! okToProceed() )
 			return false;
 		m_din >> c;
 		m_bytes++;
-		line += TQChar(c).ascii();
+		line += TQChar(c).latin1();
 		if ( c == '\n' )
 			break;
 	}
-	return true;	
+	return true;
 }
 
 #include "responseprotocol.moc"
diff --git a/kopete/protocols/msn/Makefile.am b/kopete/protocols/msn/Makefile.am
index ffecef3c..d4fe5bec 100644
--- a/kopete/protocols/msn/Makefile.am
+++ b/kopete/protocols/msn/Makefile.am
@@ -10,6 +10,7 @@ AM_CPPFLAGS = -Iui \
 	-I$(srcdir)/webcam \
 	-I$(srcdir)/ui \
 	$(KOPETE_INCLUDES) \
+	-I$(top_srcdir)/kopete/libkopete/private \
 	$(all_includes)
 
 kde_module_LTLIBRARIES = kopete_msn.la
diff --git a/kopete/protocols/msn/msnswitchboardsocket.cpp b/kopete/protocols/msn/msnswitchboardsocket.cpp
index 896de926..b0052552 100644
--- a/kopete/protocols/msn/msnswitchboardsocket.cpp
+++ b/kopete/protocols/msn/msnswitchboardsocket.cpp
@@ -54,7 +54,7 @@
 #include "kopetemessage.h"
 #include "kopetecontact.h"
 #include "kopeteuiglobal.h"
-#include "private/kopeteemoticons.h"
+#include "kopeteemoticons.h"
 //#include "kopeteaccountmanager.h"
 //#include "kopeteprotocol.h"
 
diff --git a/kopete/protocols/yahoo/libkyahoo/sendfiletask.cpp b/kopete/protocols/yahoo/libkyahoo/sendfiletask.cpp
index 11844cd8..b63edcc7 100644
--- a/kopete/protocols/yahoo/libkyahoo/sendfiletask.cpp
+++ b/kopete/protocols/yahoo/libkyahoo/sendfiletask.cpp
@@ -205,7 +205,7 @@ void SendFileTask::connectSucceeded()
 	}
 	else
 	{
-		kdDebug(YAHOO_RAW_DEBUG) << k_funcinfo << "Error opening file: " << m_file.errorString().data() << endl;
+		kdDebug(YAHOO_RAW_DEBUG) << k_funcinfo << "Error opening file: " << m_file.errorString().ascii() << endl;
 		client()->notifyError( i18n( "An error occurred while sending the file." ), m_file.errorString(), Client::Error );
 		setError();
 		return;
diff --git a/kopete/protocols/yahoo/libkyahoo/sendpicturetask.cpp b/kopete/protocols/yahoo/libkyahoo/sendpicturetask.cpp
index 32500f1c..36998612 100644
--- a/kopete/protocols/yahoo/libkyahoo/sendpicturetask.cpp
+++ b/kopete/protocols/yahoo/libkyahoo/sendpicturetask.cpp
@@ -104,7 +104,7 @@ void SendPictureTask::connectSucceeded()
 	}
 	else
 	{
-		kdDebug(YAHOO_RAW_DEBUG) << "Error opening file: " << file.errorString().data() << endl;
+		kdDebug(YAHOO_RAW_DEBUG) << "Error opening file: " << file.errorString().ascii() << endl;
 		client()->notifyError(i18n("Error opening file: %1").tqarg(m_path), file.errorString(), Client::Error );
 		return;
 	}
diff --git a/kopete/protocols/irc/ircsignalhandler.h b/kopete/protocols/irc/ircsignalhandler.h
index 2571a897..ad986238 100644
--- a/kopete/protocols/irc/ircsignalhandler.h
+++ b/kopete/protocols/irc/ircsignalhandler.h
@@ -45,7 +45,7 @@
 * up the contact it is for, and call the function passed into the class by the
 * mapping function.
 *
 * Since TQObjects cannot be inside templates, the TQMember classes that connect
 * to the slots are seperate.
 */
 
@@ -81,13 +81,13 @@ TQObject members, these connect to the KIRC signals and call
 the Mapping functions when they emit.
 **/
 
-class TQMember : public TQObject
+class QMember : public TQObject
 {
 	Q_OBJECT
   TQ_OBJECT
 
 	public:
-		TQMember( IRCSignalMappingT *m, TQObject *p ) : TQObject( p ), mapping( m ){};
+		QMember( IRCSignalMappingT *m, TQObject *p ) : TQObject( p ), mapping( m ){};
 
 	public slots:
 		void slotEmit( const TQString &id )
@@ -100,13 +100,13 @@ class TQMember : public TQObject
 		IRCSignalMappingT *mapping;
 };
 
-class TQMemberSingle : public TQObject
+class QMemberSingle : public TQObject
 {
 	Q_OBJECT
   TQ_OBJECT
 
 	public:
-		TQMemberSingle( IRCSignalMappingSingleT *m, TQObject *p ) : TQObject( p ), mapping( m ){}
+		QMemberSingle( IRCSignalMappingSingleT *m, TQObject *p ) : TQObject( p ), mapping( m ){}
 
 	public slots:
 		void slotEmit( const TQString &id, const TQString &arg )
@@ -119,13 +119,13 @@ class TQMemberSingle : public TQObject
 		IRCSignalMappingSingleT *mapping;
 };
 
-class TQMemberDouble : public TQObject
+class QMemberDouble : public TQObject
 {
 	Q_OBJECT
   TQ_OBJECT
 
 	public:
-		TQMemberDouble( IRCSignalMappingDoubleT *m, TQObject *p ) : TQObject( p ), mapping( m ){}
+		QMemberDouble( IRCSignalMappingDoubleT *m, TQObject *p ) : TQObject( p ), mapping( m ){}
 
 	public slots:
 		void slotEmit( const TQString &id, const TQString &arg, const TQString &arg2 )
@@ -138,13 +138,13 @@ class TQMemberDouble : public TQObject
 		IRCSignalMappingDoubleT *mapping;
 };
 
-class TQMemberTriple : public TQObject
+class QMemberTriple : public TQObject
 {
 	Q_OBJECT
   TQ_OBJECT
 
 	public:
-		TQMemberTriple( IRCSignalMappingTripleT *m, TQObject *p ) : TQObject( p ), mapping( m ){}
+		QMemberTriple( IRCSignalMappingTripleT *m, TQObject *p ) : TQObject( p ), mapping( m ){}
 
 	public slots:
 		void slotEmit( const TQString &id, const TQString &arg, const TQString &arg2, const TQString &arg3 )
@@ -293,7 +293,7 @@ class IRCSignalHandler : public TQObject
 			IRCSignalMappingT *mapping = new IRCSignalMapping<TClass>( m, signal, method );
 			mappings.append(mapping);
 			TQObject::connect( static_cast<IRCAccount*>( m->mySelf()->account() )->engine(), signal,
-				new TQMember( mapping, this),
+				new QMember( mapping, this),
 				TQT_SLOT( slotEmit( const TQString &) )
 			);
 		}
@@ -305,7 +305,7 @@ class IRCSignalHandler : public TQObject
 			IRCSignalMappingSingleT *mapping = new IRCSignalMappingSingle<TClass>( m, signal, method );
 			mappings.append(mapping);
 			TQObject::connect( static_cast<IRCAccount*>( m->mySelf()->account() )->engine(), signal,
-				new TQMemberSingle( mapping, this),
+				new QMemberSingle( mapping, this),
 				TQT_SLOT( slotEmit( const TQString &, const TQString &) )
 			);
 		}
@@ -317,7 +317,7 @@ class IRCSignalHandler : public TQObject
 			IRCSignalMappingDoubleT *mapping = new IRCSignalMappingDouble<TClass>( m, signal, method );
 			mappings.append(mapping);
 			TQObject::connect( static_cast<IRCAccount*>( m->mySelf()->account() )->engine(), signal,
-				new TQMemberDouble( mapping, this),
+				new QMemberDouble( mapping, this),
 				TQT_SLOT( slotEmit( const TQString &, const TQString &,const TQString &) )
 			);
 		}
@@ -330,7 +330,7 @@ class IRCSignalHandler : public TQObject
 			IRCSignalMappingTripleT *mapping = new IRCSignalMappingTriple<TClass>( m, signal, method );
 			mappings.append(mapping);
 			TQObject::connect( static_cast<IRCAccount*>( m->mySelf()->account() )->engine(), signal,
-				new TQMemberTriple( mapping, this),
+				new QMemberTriple( mapping, this),
 				TQT_SLOT( slotEmit( const TQString &, const TQString &,const TQString &,const TQString &) )
 			);
 		}
@@ -45,7 +45,7 @@
 * mapping function.
 *
-* Since TQObjects cannot be inside templates, the TQMember classes that connect
+* Since TQObjects cannot be inside templates, the QMember classes that connect
 * to the slots are seperate.
 */
-- 
cgit v1.2.3

